from apadata.text_processors.evaluators.spelling_evaluator import SpellingEvaluator


def test_spelling_evaluator():
    language = "en"
    evaluator = SpellingEvaluator(language=language)
    keyword = "Consulting"
    assert evaluator.evaluate(keyword) == 1.0
    keyword = "Consutlining"
    assert evaluator.evaluate(keyword) == 0.0
    evaluator = SpellingEvaluator()
    assert evaluator.evaluate("Consulting") == 1.0
    evaluator = SpellingEvaluator()
    assert evaluator.evaluate("La revedere amici") == 1.0
